@@ -4,8 +4,7 @@
 #                                                                                 
 #    This program is free software; you can redistribute it and/or modify         
 #    it under the terms of the GNU General Public License as published by         
-#    the Free Software Foundation; either version 2 of the License, or            
-#    (at your option) any later version.                                          
+#    the Free Software Foundation, version 2.                                      
 #                                                                                 
 #    This program is distributed in the hope that it will be useful,              
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of               
@@ -33,7 +32,10 @@ from Products.CMFPlone.utils import getToolByName
 from collective.contentlicensing import ContentLicensingMessageFactory as _
 from Products.CMFCore.interfaces import IPropertiesTool, IMetadataTool
 from plone.app.controlpanel.form import ControlPanelForm
-from plone.fieldsets import FormFieldsets
+try:
+    from plone.fieldsets import FormFieldsets
+except ImportError:
+    from plone.fieldsets.fieldsets import FormFieldsets
 from plone.app.form.validators import null_validator
 from widgets import LicenseWidget
 from plone.app.controlpanel.widgets import MultiCheckBoxVocabularyWidget 
